@@ -6,81 +6,12 @@ use warnings;
 
 use Padre::Wx ();
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 our @ISA     = 'Padre::Document';
 
 # max lines to display in a calltip
 my $CALLTIP_DISPLAY_COUNT = 10;
 
-# colorize timer to make sure that colorize tasks are scheduled properly...
-my $COLORIZE_TIMER;
-my $COLORIZE_TIMEOUT = 100; # wait n-millisecond before starting the Perl6 colorize task
-
-sub text_with_one_nl {
-	my $self = shift;
-	my $text = $self->text_get;
-	my $nlchar = "\n";
-	if ( $self->get_newline_type eq 'WIN' ) {
-		$nlchar = "\r\n";
-	}
-	elsif ( $self->get_newline_type eq 'MAC' ) {
-		$nlchar = "\r";
-	}
-	$text =~ s/$nlchar/\n/g;
-	return $text;
-}
-
-# colorizes a Perl 6 document in a timer
-# one at a time;
-# now the user can choose between PGE and STD colorizers
-# via the preferences
-sub colorize {
-	my $self = shift;
-	
-	my $config = Padre::Plugin::Perl6::plugin_config();
-	if($config->{p6_highlight} || $self->{force_p6_highlight}) {
-	
-		my $timer_id = Wx::NewId();
-		my $main = Padre->ide->wx->main;
-		$COLORIZE_TIMER = Wx::Timer->new($main, $timer_id);
-		Wx::Event::EVT_TIMER(
-			$main, $timer_id, 
-			sub { 
-				# temporary overlay using the parse tree given by parrot
-				my $colorizer = $config->{colorizer};
-				my $task;
-				if($colorizer eq 'STD') {
-					# Create an STD coloring task 
-					require Padre::Plugin::Perl6::Perl6StdColorizerTask;
-					$task = Padre::Plugin::Perl6::Perl6StdColorizerTask->new(
-						text => $self->text_with_one_nl,
-						editor => $self->editor,
-						document => $self);
-				} else {
-					# Create a PGE coloring task
-					require Padre::Plugin::Perl6::Perl6PgeColorizerTask;
-					$task = Padre::Plugin::Perl6::Perl6PgeColorizerTask->new(
-						text => $self->text_with_one_nl,
-						editor => $self->editor,
-						document => $self);
-				}
-				# hand off to the task manager
-				$task->schedule();
-
-				# and let us schedule that it is running properly or not
-				if($task->is_broken) {
-					# let us reschedule colorizing task to a later date..
-					$COLORIZE_TIMER->Stop;
-					$COLORIZE_TIMER->Start( $COLORIZE_TIMEOUT, Wx::wxTIMER_ONE_SHOT );
-				}
-			},
-		);
-
-		# let us reschedule colorizing task to a later date..
-		$COLORIZE_TIMER->Stop;
-		$COLORIZE_TIMER->Start( $COLORIZE_TIMEOUT, Wx::wxTIMER_ONE_SHOT );
-	}
-}
 
 # get Perl6 (rakudo) command line for "Run script" F5 Padre menu item
 sub get_command {
@@ -914,4 +845,4 @@ Gabor Szabo L<http://szabgab.com/>
 Copyright 2008-2009 Padre Developers as in Perl6.pm
 
 This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
\ No newline at end of file
+modify it under the same terms as Perl 5 itself.
