@@ -7,10 +7,9 @@ use Class::XSAccessor accessors => {
 	_plugin           => '_plugin',           # plugin to be configured
 	_sizer            => '_sizer',            # window sizer
 	_colorizer_cb     => '_colorizer_cb',      # colorizer on/off checkbox
-	_colorizer_list   => '_colorizer_list',    # colorizer list box
 };
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 use Padre::Current;
 use Padre::Wx ();
@@ -61,8 +60,6 @@ sub _on_ok_button_clicked {
 	my $old_p6_highlight = $prefs->{p6_highlight};
 	my $old_colorizer = $prefs->{colorizer};
 	$prefs->{p6_highlight} = $self->_colorizer_cb->GetValue();
-	$prefs->{colorizer} = ($self->_colorizer_list->GetSelection() == 0) ? 
-		'STD' : 'PGE';
 
 	# store plugin preferences
 	$plugin->config_write($prefs);
@@ -121,26 +118,9 @@ sub _create_controls {
 		Wx::CheckBox->new( $self, -1, Wx::gettext('Enable coloring'))
 	);
 	
-	my @choices = [
-		'S:H:P6/STD',
-		'Rakudo/PGE'
-	];
-	# syntax highligher selection
-	my $colorizer_list_label = Wx::StaticText->new( $self, -1, Wx::gettext('Colorizer:') );
-	$self->_colorizer_list( 
-		Wx::ListBox->new(
-			$self,
-			-1,
-			Wx::wxDefaultPosition,
-			[150,50],
-			@choices,
-		)
-	);
-	
 	# Select based on configuration parameters
 	my $config = $self->_plugin->config;
 	$self->_colorizer_cb->SetValue( $config->{p6_highlight} );
-	$self->_colorizer_list->Select( $config->{colorizer} eq 'STD' ? 0 : 1);
 	
 	# pack the controls in a box
 	my $box;
@@ -148,11 +128,6 @@ sub _create_controls {
 	$box->Add( $self->_colorizer_cb, 1, Wx::wxALL|Wx::wxEXPAND|Wx::wxALIGN_CENTER, 5 );
 	$self->_sizer->Add( $box, 0, Wx::wxALL|Wx::wxEXPAND|Wx::wxALIGN_CENTER, 5 );
 
-	$box = Wx::BoxSizer->new(Wx::wxHORIZONTAL);
-	$box->Add( $colorizer_list_label, 0, Wx::wxALL|Wx::wxEXPAND|Wx::wxALIGN_CENTER, 5 );
-	$box->Add( $self->_colorizer_list, 1, Wx::wxALL|Wx::wxEXPAND|Wx::wxALIGN_CENTER, 5 );
-	$self->_sizer->Add( $box, 0, Wx::wxALL|Wx::wxEXPAND|Wx::wxALIGN_CENTER, 5 );
-
 }
 
 
